
#include	<Types.r>
#include	<SysTypes.r>

resource 'vers' (1,purgeable) {
	0x01,
	0x02,
	release,
	0x07,
	verJapan,
	"ver.A.02.07",
	"GLOBALBASE COSMOS ver.A.02.07 for Macintosh"
};


type 'carb' {
};


resource 'carb'(0) {
};